/**
 *****************************************************************************
   @example  AD5144.c
   @brief    SPI control AD5144

   @version V0.1
   @author  ADI	  YuanXiankun
   @date   July 2nd   2013

 
              
All files for ADuCM360/361 provided by ADI, including this file, are
provided  as is without warranty of any kind, either expressed or implied.
The user assumes any and all risk from the use of this code.
It is the responsibility of the person integrating this code into an application
to ensure that the resulting application performs as required and is safe.


**/



#include <stdio.h>
#include <string.h>
#include <ADuCM360.h>

#include "UrtLib.h"
#include "ClkLib.h"
#include "WdtLib.h"
#include "SPI.h"

void UARTINIT (void);
void delay(long int);

int main (void)
{
   WdtCfg(T3CON_PRE_DIV1,T3CON_IRQ_EN,T3CON_PD_DIS); // Disable Watchdog timer resets
   
   //Disable clock to unused peripherals
   ClkDis(CLKDIS_DISSPI0CLK|CLKDIS_DISSPI1CLK|CLKDIS_DISI2CCLK|CLKDIS_DISPWMCLK|CLKDIS_DIST0CLK|CLKDIS_DIST1CLK); // Only enable clock to used blocks
   ClkCfg(CLK_CD0,CLK_HF,CLKSYSDIV_DIV2EN,CLK_UCLKCG);// Select CD0 for CPU clock with 8MHz UCLK (div2 enabled on oscillator output)
   ClkSel(CLK_CD7,CLK_CD7,CLK_CD0,CLK_CD7);           // Select CD0 for UART System clock
   
   UARTINIT();                                        // Init Uart
   Aducm360_SPI_initial();							  // Initial SPI

  

    WriteToAD5144ViaSPI(0xb0,0x00);	// software reset
	delay(1000);
	WriteToAD5144ViaSPI(0xd0,0x01);	// enable write to  rdac
	delay(1000);
	WriteToAD5144ViaSPI(0x12,0x55);  // write RDAC3, serial data to RDAC3 
	delay(1000); 		 
	AD5144Data= ReadFromAD5144ViaSPI(0x32,0x03);	   //read back, data register of Rdac3 
   	delay(1000);
    while (1)
   {
	   UrtTx(pADI_UART,AD5144Data);			
	   delay(1000);
   }
}








