/**
 *****************************************************************************
   @example  SPI.c
   @brief    GPIO simulate SPI example	by aducm360


   @version V0.1
   @author  ADI	.YuanXiankun
   @date    June 2013

              
All files for ADuCM360/361 provided by ADI, including this file, are
provided  as is without warranty of any kind, either expressed or implied.
The user assumes any and all risk from the use of this code.
It is the responsibility of the person integrating this code into an application
to ensure that the resulting application performs as required and is safe.
**/

#include <stdio.h>
#include <string.h>
#include <ADuCM360.h>

#include "SPI.h"
#include "urtlib.h"

unsigned char AD5144Data;

// Simple Delay routine
extern void delay (long int length)
{
	while (length >0)
    	length--;
}

void Aducm360_SPI_initial(void)
{
	pADI_GP1->GPCON &= 0x00;  //GP1 config as GPIO
    pADI_GP1->GPOEN = 0xfd;   //GP1.1 input, other bits output.
	pADI_GP1->GPSET |= 0x20;	//GP1.5 high   as_RSout  state
	pADI_GP1->GPSET |= 0x40;	//GP1.6 high   as_RSin state
}

void Aducm360_output_SCLK_high(void)
{
	 pADI_GP1->GPSET |= 0x08;	//GP1.3 high
	
}

void Aducm360_output_SCLK_low(void)
{
	 pADI_GP1->GPCLR |= 0x08;	//GP1.3 low
}

void Aducm360_output_CNV_high(void)
{
	 pADI_GP1->GPSET |= 0x10;	//GP1.4 high
	
}

void Aducm360_output_CNV_low(void)
{
	 pADI_GP1->GPCLR |= 0x10;	//GP1.4 low
}

void Aducm360_output_SDIO_high(void)
{
	 pADI_GP1->GPSET |= 0x04;	//GP1.2 high
	
}

void Aducm360_output_SDIO_low(void)
{
	 pADI_GP1->GPCLR |= 0x04;	//GP1.2 low
}

/*******************************************************************
*   Function:    WriteToAD5144ViaSPI
*   Description: write to the AD5144 via the SPI port.
*******************************************************************/
void WriteToAD5144ViaSPI(unsigned char RegAddress,unsigned char RegValue)
{
	unsigned char ControlAddress = 0;
	unsigned char ControlValue = 0;
	unsigned char i = 0;
	ControlAddress = RegAddress;
	ControlValue = RegValue;
	Aducm360_output_CNV_high();
	
	delay(1000);
	Aducm360_output_CNV_low(); 
	delay(1000);
	Aducm360_output_SCLK_high();	
	//write  register address
	for(i=0; i<8; i++)
	{
		Aducm360_output_SCLK_high();
		delay(1000);
		//write register code
		if(0x80 == (ControlAddress & 0x80))
		{
			Aducm360_output_SDIO_high();	 
		}
		else
		{
			Aducm360_output_SDIO_low();	  
		}
		ControlAddress <<= 1;	//Rotate data
		delay(1000);
		Aducm360_output_SCLK_low();
		delay(1000);

	}

	//write the register value
	for(i=0; i<8; i++)
	{
		Aducm360_output_SCLK_high();
		delay(1000);
		if(0x80 == (ControlValue & 0x80))
		{
			Aducm360_output_SDIO_high();	  
		}
		else
		{
			Aducm360_output_SDIO_low();	  
		}
		ControlValue <<= 1;	//Rotate data

		delay(1000);
		Aducm360_output_SCLK_low();
		delay(1000);

	}

	Aducm360_output_CNV_high();	//bring CS high again
	delay(1000);
}

/*******************************************************************
*   Function:    ReadFromAD5144ViaSPI
*   Description: read to the AD5144 via the SPI port.
*******************************************************************/
unsigned int ReadFromAD5144ViaSPI(unsigned char RegAddress, unsigned char Datavalue)
{
	unsigned char ControlValue = 0;
	unsigned char value=0;
	unsigned char i = 0;

	ControlValue = RegAddress;
	Aducm360_output_SCLK_low();	
	Aducm360_output_CNV_low();
	//Write Control register and Read result data
	for(i=0; i<8; i++)
	{
		Aducm360_output_SCLK_high();
		delay(1000);
		//write register code
		if(0x80 == (ControlValue & 0x80))
		{
			Aducm360_output_SDIO_high();	  
		}
		else
		{
			Aducm360_output_SDIO_low();	  
		}
		ControlValue <<= 1;	//Rotate data
		delay(1000);
		Aducm360_output_SCLK_low();
		delay(1000);

	}
	for(i=0; i<8; i++)
	{
		Aducm360_output_SCLK_high();
		delay(1000);
		if(0x80 == (Datavalue & 0x80))
		{
			Aducm360_output_SDIO_high();	  
		}
		else
		{
			Aducm360_output_SDIO_low();	  
		}
		Datavalue <<= 1;	//Rotate data
		delay(1000);
		Aducm360_output_SCLK_low();
		delay(1000);
		if(i==7)
		{
				Aducm360_output_CNV_high();	
				delay(1000);
				Aducm360_output_CNV_low();	
		} 
		delay(1000);
	} 
	for(i=0; i<8; i++)
	{
		Aducm360_output_SCLK_high();
		delay(1000);
		Aducm360_output_SCLK_low();
		delay(1000);
	}  
	for(i=0; i<8; i++)
	{
		Aducm360_output_SCLK_high();
		delay(1000);
		value <<=1;
		if((pADI_GP1->GPIN&0x02)== 0x02)  
         {
		 	value |= 0x01;  
		 }
     	else  
         {
		 	value &= ~0x01;
		 }
		delay(1000);
		Aducm360_output_SCLK_low();
		delay(1000);
	}
	Aducm360_output_CNV_high();	//bring CS high again
	delay(1000);
	AD5144Data=value;
	return AD5144Data;
}
